@@ -49,6 +49,10 @@ public:
   void Write(FILE *file);
   void Read(FILE *file);
   int Latex(FILE *file, char fragile);
+
+  // what appears in the minibuffer when opening
+  const char* EditMessage() {return "Opened figure";}
+
   void Edit(int, int);
   char Editable();
   char Deletable();
