@@ -196,6 +196,8 @@ public:
   void Read(FILE *file);
   int Latex(FILE *file, char fragile);
   char AutoDelete();
+  // what appears in the minibuffer when opening
+  const char* EditMessage() {return "Opened error";}
   void Edit(int, int);
   char Editable();
   Inset* Clone();
@@ -220,6 +222,8 @@ public:
   void Write(FILE *file);
   void Read(FILE *file);
   int Latex(FILE *file, char fragile);
+  // what appears in the minibuffer when opening
+  const char* EditMessage() {return "Opened note";}
   void Edit(int, int);
   char Editable();
   char LyxCode();
