@@ -35,8 +35,8 @@ extern void NounCB(FL_OBJECT *, long);
 extern void MarginCB(FL_OBJECT *, long);
 extern void FigureCB(FL_OBJECT *, long);
 extern void TableCB(FL_OBJECT *, long);
-extern void CutCB(FL_OBJECT *, long);
-extern void PasteCB(FL_OBJECT *, long);
+extern void CutCB();
+extern void PasteCB();
 extern void MeltCB(FL_OBJECT *, long);
 extern void TexCB(FL_OBJECT *, long);
 extern void FormulaCB(FL_OBJECT *, long);
