@@ -24,6 +24,10 @@ public:
   virtual int Width(LyXFont font)=0;
   virtual LyXFont ConvertFont(LyXFont font);
   virtual void Draw(LyXFont font, unsigned long  pm, int baseline, float &x)=0;
+
+  // what appears in the minibuffer when opening
+  virtual const char* EditMessage() {return "Opened inset";}
+
   virtual void Edit(int, int);
   virtual char Editable();
   virtual char AutoDelete();
@@ -41,6 +45,7 @@ public:
   // Provisional hack to handle labels ale260796
   virtual char* GetLabel() { return (char*)NULL; }
 
+
   // used for autocorrection
   virtual Bool IsEqual(Inset* /*other*/){
     return False;
