@@ -129,7 +129,7 @@ public:
   ~LyXText();
    
   /* what you expect when pressing <enter> at cursor position */ 
-  void BreakParagraph();
+  void BreakParagraph(char keep_layout = 0);
    
   /* set layout over selection and make a total rebreak of those  paragraphs */
   void SetLayout(char layout);
@@ -347,6 +347,7 @@ public:
    void InsertCharInTable(char c);
    void BackspaceInTable();
    void CheckParagraphInTable(LyXParagraph* par, int pos);
+  char HitInTable(Row* row, int x);
    /* table stuff -- end*/
 
   LyXParagraph* GetParFromID(int id);
