@@ -79,13 +79,15 @@ enum LyxMathTextCodes  {
    LM_TC_TEXTRM,
    LM_TC_TEX,
    LM_TC_BOP,                //  Internal code for operators  
-   LM_TC_SYMB,	               //  Internal code for symbols
-   LM_TC_BSYM,                 //  Big non-operator symbols 
-     
-   LM_TC_DISPLAY,              //  Styles (font sizes)
+  
+   LM_TC_SYMB,	             //  Internal code for symbols
+   LM_TC_BOPS,               //  symbolic operators 
+   LM_TC_BSYM,               //  Big non-operator symbols 
+      
+/*   LM_TC_DISPLAY,              //  Styles (font sizes)
    LM_TC_TEXT,
    LM_TC_SCRIPT,
-   LM_TC_SCRIPTSCRIPT,
+   LM_TC_SCRIPTSCRIPT, */
      
    LM_TC_MAX                   //  This must be < 32 
 };
@@ -116,6 +118,12 @@ enum LyxMathInsetTypes  {
    LM_OT_MAX
 };
 
+enum MathedBinaryTypes {
+    LMB_NONE = 0,
+    LMB_RELATION,
+    LMB_OPERATOR,
+    LMB_BOP = (LMB_RELATION | LMB_OPERATOR)
+};
 
 class LyxMathInset;
 class MathParInset;
@@ -136,7 +144,8 @@ class LyxMathIter {
    Bool IsInset();
    Bool IsActive();
    Bool IsFont();
-   Bool IsScript();
+   bool IsScript();
+   bool IsTab();
    virtual void Reset(void);
    virtual void Insert(byte, LyxMathTextCodes c=LM_TC_CONST);
    virtual void Insert(LyxMathInset*, int t=LM_TC_INSET);
@@ -147,14 +156,15 @@ class LyxMathIter {
    void SetData(LyxArrayBase *a) { array = a; Reset(); }
    LyxArrayBase *GetData(void) { return array; }
    
-      // Copy every object from position p1 to p2
+   // Copy every object from position p1 to p2
    LyxArrayBase *Copy(int p1=0, int p2=10000);
    
    // Delete every object from position p1 to p2
    void Clean(int p1=0, int p2=10000);
-   void Merge(LyxArrayBase*);
+   void Merge(LyxArrayBase*, int nc=0);
  protected:
    void split(int);
+   void join(int);
    short fcode;
    int pos;
    LyxArrayBase *array;
@@ -178,12 +188,6 @@ class LyxMathInset  {
    
    // Metrics & position
    virtual void Metrics(void)=0;   // Compute the size of the object
-   //INLINE virtual int Ascent(void) const;
-   //INLINE virtual int Descent(void) const;
-   //INLINE virtual int Width(void) const;
-   //INLINE virtual int Height(void) const;
-     // it is not needed to use inline in the declaration, it is enough
-     // to do that in the definition.
    virtual int Ascent(void) const { return ascent; }
    virtual int Descent(void) const { return descent; }
    
@@ -193,17 +197,14 @@ class LyxMathInset  {
    virtual void SetLimits(bool) { }   
       
    // Identification    
-   //INLINE char *GetName(void) const;
-   //INLINE short GetType(void) const;
-   //INLINE short GetStyle(void) const;
    char *GetName(void) const { return name; }
    short GetType(void) const { return objtype; }
    short GetStyle(void) const { return size; }
    
-   // Don't use these functions if it's not sctrictly necessary
-   virtual void  SetType(short);
-   virtual void  SetStyle(short);
-   virtual void  SetName(char*);
+   // Don't use these functions if it's not strictly necessary
+   virtual void  SetType(short t) { objtype = t; }
+   virtual void  SetStyle(short st) { size = st; Metrics(); }
+   virtual void  SetName(char* n) { name = n; }
  
  protected:
    char *name;
@@ -227,13 +228,13 @@ class MathParInset: public LyxMathInset  {
    // Write LaTeX code
    virtual void Write(FILE *file);
    virtual void Metrics(void);
+   virtual void UserSetSize(short);
  
    // Data is stored in a LyxArray
    virtual void SetData(LyxArrayBase *);
-   virtual LyxArrayBase * GetData(void);
+   virtual LyxArrayBase * GetData(void) { return array; }
 
    // Cursor position inside the paragraph 
-	//INLINE virtual void GetXY(int& x, int& y) const;
    virtual void GetXY(int& x, int& y) const;
    virtual void SetFocus(int,int) { };
    virtual bool Inside(int, int);   
@@ -242,15 +243,21 @@ class MathParInset: public LyxMathInset  {
    virtual void SetAlign(char, char*) { };
    virtual int GetTabPos(void) { return 0; }
    virtual int GetTab(int /*i=1*/) { return 0; }
+   virtual int GetColumns() { return 1; }
+   virtual int GetRows() { return 1; }
    
    // Vertical switching 
    virtual bool Up(void) { return false; }
    virtual bool Down(void) { return false; }
+   virtual void Top(void) { }
+   virtual void Bottom(void) { }
+   virtual void SetStyle(short sz) {if (!fixedsz) LyxMathInset::SetStyle(sz);}
  protected: 
    virtual void SetTab(int) { }
    LyxArrayBase *array;
    int xo, yo;  // Cursor start position
  private:
+   bool fixedsz;
    friend class InsetFormula;
 };
 
@@ -269,8 +276,12 @@ class MathMatrixInset: public MathParInset {
    void SetFocus(int,int);
    void AddRow(void);
    bool DelRow(void);
+
    bool Up(void);
    bool Down(void);
+   void Top(void);
+   void Bottom(void);
+
    void SetAlign(char, char*);
    char *GetAlign(char* vv) {
       *vv = v_align;
@@ -278,37 +289,54 @@ class MathMatrixInset: public MathParInset {
    }
    int GetTab(int i=1);
    int GetTabPos(void) { return ct; }
+   int GetColumns() { return nc; }
+   int GetRows() { return nr; }
+   int GetRowIdx();
+    
+   // Labeling and numbering stuff
+   void SetLabel(char* l) { crow->label = l; }
+   const char* GetLabel(void) { return crow->label; }
+   bool IsNumbered(void) {  return crow->numbered; }
+   void SetNumbered(bool nf) { crow->numbered = nf; }
  protected:
    bool mflag;
    void SetTab(int);
-   int nc;          //  Number of columns
+   int nc, nr;    //  Number of columns & rows
    int ct, *ws;   //  Current tab & tabs
    char v_align;
    char* h_align;
    struct rowst {
       int asc, desc, y;
       int *w; 
+      char *label;
+      bool numbered;
       LyxArrayBase *array;
       rowst *prev, *next;
       rowst(int n) {
 	 w = new int[n+1];
 	 array = NULL;
+	 label = NULL;
+	 numbered = true;
       }      
       ~rowst() {
 	 delete[] w;
 	 delete array;
+	 if (label) delete[] label;
       }      
-   } *row, *crow; 
+   } *row, *crow;
 };
 
 
+
 /*************************  Prototypes  **********************************/
  
 LyxArrayBase *mathed_parse(unsigned flags=0, LyxArrayBase *data=NULL, MathParInset **mt=NULL);
 
 void mathed_write(MathParInset*, FILE *, int*, char fragile, const char* label=NULL);
  
-void mathed_parser_file(FILE* file);
+void mathed_parser_file(FILE*);
+
+int MathedLookupBOP(short);
 
 /************************ Inline functions ********************************/
 
@@ -327,6 +355,18 @@ void mathed_parser_file(FILE* file);
 
 #define MathIsScript(x)  ((x)==LM_TC_DOWN || (x)==LM_TC_UP)  
 
+#define MathIsBOPS(x)    (MathedLookupBOP(x)>LMB_NONE)
+
+
+inline bool MathIsBinary(short x)
+{
+    return (x==LM_TC_BOP || x==LM_TC_BOPS);
+}
+
+inline bool MathIsSymbol(short x) {
+    return (LM_TC_SYMB<=x && x<=LM_TC_BSYM);
+}
+
 inline
 Bool LyxMathIter::IsInset()
 {
@@ -347,13 +387,19 @@ Bool LyxMathIter::IsFont()
 
 
 inline
-Bool LyxMathIter::IsScript()
+bool LyxMathIter::IsScript()
 {
    return MathIsScript(array->bf[pos]);
 }   
 
 inline
-LyxMathIter::LyxMathIter(void)
+bool LyxMathIter::IsTab()
+{
+   return (array->bf[pos]==LM_TC_TAB);
+}   
+
+inline
+LyxMathIter::LyxMathIter()
 {
    pos = 0;
    fcode = 0;
@@ -380,91 +426,6 @@ LyxMathInset::LyxMathInset(char *nm, short ot, short st):
    width = ascent = descent = 0;
 }
 
-inline 
-LyxMathInset::LyxMathInset(LyxMathInset* inset) 
-{
-   if (inset) {
-      name = inset->GetName();
-      objtype = inset->GetType();
-      size = inset->GetStyle();
-      width = inset->Width();
-      ascent = inset->Ascent();
-      descent = inset->Descent();
-   } else {
-      objtype = LM_OT_UNDEF;
-      size = LM_ST_TEXT;
-      width = ascent = descent = 0;
-      name = NULL;
-   }
-}
-
-#if 0
-inline
-int LyxMathInset::Height(void) const
-{
-   return ascent + descent;
-}
-
-inline
-int LyxMathInset::Width(void) const
-{
-   return width;
-}
-
-inline
-int LyxMathInset::Ascent(void) const
-{
-   return ascent;
-}
-
-inline
-int LyxMathInset::Descent() const
-{
-   return descent;
-}
-#endif
-
-// Actually another solution than commenting out the definitions, would be
-// to move them to right after the class definition. So that one can be sure
-// that the inlined functions are not used before defined.
-
-// inline
-// char *LyxMathInset::GetName(void) const
-// {
-//    return name;
-// }
-
-// inline    
-// short LyxMathInset::GetType(void) const
-// {
-//    return objtype;       
-// }
-
-// inline
-// short LyxMathInset::GetStyle(void) const
-// {
-//    return size;       
-// }
-
-inline    
-void LyxMathInset::SetType(short t)
-{
-   objtype = t;       
-}
-
-inline
-void LyxMathInset::SetStyle(short st)
-{
-   size = st;      
-   Metrics();
-}
- 
-inline
-void LyxMathInset::SetName(char* n)
-{
-   name = n;      
-}
-
 inline
 bool MathParInset::Inside(int x, int y) 
 {
@@ -485,11 +446,13 @@ void MathParInset::GetXY(int& x, int& y) const
 }
 
 inline
-LyxArrayBase *MathParInset::GetData()
+void MathParInset::UserSetSize(short sz)
 {
-   return array;
+   if (sz>=0) {
+       size = sz;      
+       fixedsz = true;
+   }
 }
 
-
 #endif
 
