@@ -24,6 +24,6 @@ void ReplaceWord(const char* replacestringstring);
 /* this function has to be implented by the spell checker.
  * It will show the spellcheker form*/ 
 void ShowSpellChecker();
-bool SpellCheckerOptions(void);
+void SpellCheckerOptions(void);
 
 #endif
