@@ -26,15 +26,19 @@
 typedef struct _WidgetRec *Widget;
 
 GC LyXGetGC(LyXFont font);
+GC LyXGetMathGC();
+GC LyXGetMathFrameGC();
 GC LyXGetClearGC();
-GC LyXGetGreenGC();
-GC LyXGetRedGC();
+GC LyXGetFillGC();
+GC LyXGetFootGC();
+GC LyXGetGC();
+GC LyXGetLatexGC();
 GC LyXGetCopyGC();
 GC LyXGetOnOffLineGC();
 GC LyXGetThinOnOffLineGC();
 GC LyXGetThickLineGC();
 GC LyXGetLightedGC();
-GC LyXGetYellowGC();
+GC LyXGetInsetGC();
 
 GC LyXGetSelectGC();
 int LyXMaxAscent(LyXFont font);
@@ -46,6 +50,9 @@ int LyXDescent(LyXFont font, char c);
 int LyXTextWidth(LyXFont font, char*s, int n);
 int LyXStringWidth(LyXFont font, char *s);
 
+void LyXDrawString(LyXFont font, char* s, Pixmap pm, int baseline, int x);
+void LyXDrawText(LyXFont font, char* s, int n, Pixmap pm, int baseline, int x);
+
 // inlined functions
 inline
 void LyXBell() {
